
Changelog
---------

0.2 (2015-01-21)
~~~~~~~~~~~~~~~~

- Change global_allow to True. See:
  https://github.com/seantis/seantis.people/issues/32
  [href]

- Show parent organization in people list #3
  [msom]

- Add PDF export of organizations #2
  [msom]

0.1 (2014-12-04)
~~~~~~~~~~~~~~~~

- Initial release.
  [msom]
